# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------
import os
import sys
from datetime import date

file_loc = os.path.split(__file__)[0]
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(file_loc), '.')))

import strongdoc

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
#sys.path.insert(0, os.path.abspath('.'))

# -- Project information -----------------------------------------------------

project = strongdoc.__about__.__project__
author = strongdoc.__about__.__author__
copyright = u'Copyright 2020 - {0} {1}'.format(date.today().year, author)

# The short X.Y version
version = strongdoc.__about__.__version__
# The full version, including alpha/beta/rc tags
release = version

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.doctest',
    'sphinx.ext.todo',
    'sphinx.ext.coverage',
    'sphinx.ext.imgmath',
    'sphinx.ext.napoleon',
    'sphinx.ext.viewcode',
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store', 'strongdoc.proto.*']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
##html_theme = 'alabaster'
##html_theme = 'agogo'
html_theme = 'nature'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# -- Options for HTMLHelp output ---------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'strongdocdoc'


# -- Options for LaTeX output ------------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'strongdoc.tex', 'StrongDoc Documentation',
     'Maxim Millen', 'manual'),
]

# -- Options for manual page output ------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'strongdoc', 'StrongDoc Documentation',
     [author], 1)
]


# -- Options for Texinfo output ----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'strongdoc', 'StrongDoc Documentation',
     author, 'eqsig', 'One line description of project.',
     'Miscellaneous'),
]


# -- Extension configuration -------------------------------------------------

# -- Options for todo extension ----------------------------------------------

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='search.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\006Search\210\001\001',
  serialized_pb=b'\n\x0csearch.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"V\n\rSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t:6\x92\x41\x33\n\x0f*\rSearchRequest2 \x12\x1e{\"query\": \"ukraine documents\"}\"\x8a\x01\n\x0eSearchResponse\x12#\n\x04hits\x18\x01 \x03(\x0b\x32\x15.proto.DocumentResult:S\x92\x41P\n\x10*\x0eSearchResponse2<\x12:{\"hits\": [{\"docID\": \"biden_investigation\", \"score\": 100}]}\".\n\x0e\x44ocumentResult\x12\r\n\x05\x64ocID\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x01\x42/\n\"com.strongsalt.strongdoc.sdk.protoB\x06Search\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='proto.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='proto.SearchRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\017*\rSearchRequest2 \022\036{\"query\": \"ukraine documents\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=155,
)


_SEARCHRESPONSE = _descriptor.Descriptor(
  name='SearchResponse',
  full_name='proto.SearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hits', full_name='proto.SearchResponse.hits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AP\n\020*\016SearchResponse2<\022:{\"hits\": [{\"docID\": \"biden_investigation\", \"score\": 100}]}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=296,
)


_DOCUMENTRESULT = _descriptor.Descriptor(
  name='DocumentResult',
  full_name='proto.DocumentResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='docID', full_name='proto.DocumentResult.docID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='proto.DocumentResult.score', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=344,
)

_SEARCHRESPONSE.fields_by_name['hits'].message_type = _DOCUMENTRESULT
DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['SearchResponse'] = _SEARCHRESPONSE
DESCRIPTOR.message_types_by_name['DocumentResult'] = _DOCUMENTRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQUEST,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:proto.SearchRequest)
  })
_sym_db.RegisterMessage(SearchRequest)

SearchResponse = _reflection.GeneratedProtocolMessageType('SearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRESPONSE,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:proto.SearchResponse)
  })
_sym_db.RegisterMessage(SearchResponse)

DocumentResult = _reflection.GeneratedProtocolMessageType('DocumentResult', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTRESULT,
  '__module__' : 'search_pb2'
  # @@protoc_insertion_point(class_scope:proto.DocumentResult)
  })
_sym_db.RegisterMessage(DocumentResult)


DESCRIPTOR._options = None
_SEARCHREQUEST._options = None
_SEARCHRESPONSE._options = None
# @@protoc_insertion_point(module_scope)



from os import path
from strongdoc import constants

import grpc


def _open_cert():
    with open(constants.CERT, 'rb') as f:
        return f.read()


def connect_to_server_with_no_auth():
    """
    Creates a secure channel to the StrongDoc Server

    :returns: channel -- A secure gRPC SSL channel.
    """
    trusted_certs = _open_cert()

    # Create the SSL and authorization token credentials
    channel_credentials = grpc.ssl_channel_credentials(root_certificates=trusted_certs)

    # Create a secure channel to the server
    channel = grpc.secure_channel('{}:{}'.format(constants.HOST, constants.PORT), channel_credentials)

    return channel


def connect_to_server_with_auth(token):
    """
    Creates a secure channel with an authentication token to the StrongDoc Server

    :param token: The user JWT token
    :type token: string
    :returns: channel -- A secure gRPC SSL channel.
    """
    trusted_certs = _open_cert()

    # Create the SSL and authorization token credentials
    channel_credentials = grpc.ssl_channel_credentials(root_certificates=trusted_certs)
    call_credentials = grpc.access_token_call_credentials(token)
    composite_credentials = grpc.composite_channel_credentials(channel_credentials, call_credentials)

    # Create a secure channel to the server
    channel = grpc.secure_channel('{}:{}'.format(constants.HOST, constants.PORT), composite_credentials)

    return channel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: billing.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='billing.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\007Billing\210\001\001',
  serialized_pb=b'\n\rbilling.proto\x12\x05proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a,protoc-gen-swagger/options/annotations.proto\">\n\x14GetBillingDetailsReq\x12&\n\x02\x61t\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xba\x05\n\x15GetBillingDetailsResp\x12/\n\x0bperiodStart\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tperiodEnd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\ttotalCost\x18\x03 \x01(\x01\x12\'\n\tdocuments\x18\x04 \x01(\x0b\x32\x14.proto.DocumentCosts\x12\"\n\x06search\x18\x05 \x01(\x0b\x32\x12.proto.SearchCosts\x12$\n\x07traffic\x18\x06 \x01(\x0b\x32\x13.proto.TrafficCosts\x12\x31\n\x10\x62illingFrequency\x18\x07 \x01(\x0b\x32\x17.proto.BillingFrequency:\x87\x03\x92\x41\x83\x03\n\x17*\x15GetBillingDetailsResp2\xe7\x02\x12\xe4\x02{\"periodStart\": \"2020-02-10T12:30:15.123Z\", \"periodEnd\": \"2020-02-29T23:59:59.999Z\", \"totalCost\": 800548.00, \"documents\": {\"cost\": 200.50, \"size\": 1000.4657}, \"search\": {\"cost\": 5.00, \"size\": 20.0}, \"traffic\": {\"cost\": 100.50, \"incoming\": 500.456, \"outgoing\": 200.564}, \"billingFrequency\": {\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}}\"\x1c\n\x1aGetBillingFrequencyListReq\"\xdb\x01\n\x1bGetBillingFrequencyListResp\x12\x35\n\x14\x62illingFrequencyList\x18\x01 \x03(\x0b\x32\x17.proto.BillingFrequency:\x84\x01\x92\x41\x80\x01\n\x1d*\x1bGetBillingFrequencyListResp2_\x12]{\"billingFrequencyList\": [{\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}]}\"\xdb\x01\n\x1aSetNextBillingFrequencyReq\x12&\n\tfrequency\x18\x01 \x01(\x0e\x32\x13.proto.TimeInterval\x12-\n\tvalidFrom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:f\x92\x41\x63\n\x1c*\x1aSetNextBillingFrequencyReq2C\x12\x41{\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}\"\xd8\x01\n\x1bSetNextBillingFrequencyResp\x12\x35\n\x14nextBillingFrequency\x18\x01 \x01(\x0b\x32\x17.proto.BillingFrequency:\x81\x01\x92\x41~\n\x1d*\x1bSetNextBillingFrequencyResp2]\x12[{\"nextBillingFrequency\": {\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}}\"\x9d\x02\n\x10\x42illingFrequency\x12&\n\tfrequency\x18\x01 \x01(\x0e\x32\x13.proto.TimeInterval\x12-\n\tvalidFrom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07validTo\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x84\x01\x92\x41\x80\x01\n\x12*\x10\x42illingFrequency2j\x12h{\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-03-01T00:00:15.123Z\", \"validTo\": \"2020-06-30T23:59:59.999Z\"}\"i\n\rDocumentCosts\x12\x0c\n\x04\x63ost\x18\x01 \x01(\x01\x12\x0c\n\x04size\x18\x02 \x01(\x01:<\x92\x41\x39\n\x10*\x0e\x44ocumentsCosts2%\x12#{\"cost\": 200.50, \"size\": 1000.4657}\"]\n\x0bSearchCosts\x12\x0c\n\x04\x63ost\x18\x01 \x01(\x01\x12\x0c\n\x04size\x18\x02 \x01(\x01:2\x92\x41/\n\r*\x0bSearchCosts2\x1e\x12\x1c{\"cost\": 5.00, \"size\": 20.0}\"\x93\x01\n\x0cTrafficCosts\x12\x0c\n\x04\x63ost\x18\x01 \x01(\x01\x12\x10\n\x08incoming\x18\x02 \x01(\x01\x12\x10\n\x08outgoing\x18\x03 \x01(\x01:Q\x92\x41N\n\x0e*\x0cTrafficCosts2<\x12:{\"cost\": 100.50, \"incoming\": 500.456, \"outgoing\": 200.564}\"k\n\x1bProcessSubscriptionEventReq\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1a\n\x12\x63ustomerIdentifier\x18\x02 \x01(\t:\"\x92\x41\x1f\n\x1d*\x1bProcessSubscriptionEventReq\"C\n\x1cProcessSubscriptionEventResp:#\x92\x41 \n\x1e*\x1cProcessSubscriptionEventResp*6\n\x0cTimeInterval\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\n\n\x06YEARLY\x10\x02\x42\x30\n\"com.strongsalt.strongdoc.sdk.protoB\x07\x42illing\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])

_TIMEINTERVAL = _descriptor.EnumDescriptor(
  name='TimeInterval',
  full_name='proto.TimeInterval',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTHLY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEARLY', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2379,
  serialized_end=2433,
)
_sym_db.RegisterEnumDescriptor(_TIMEINTERVAL)

TimeInterval = enum_type_wrapper.EnumTypeWrapper(_TIMEINTERVAL)
UNDEFINED = 0
MONTHLY = 1
YEARLY = 2



_GETBILLINGDETAILSREQ = _descriptor.Descriptor(
  name='GetBillingDetailsReq',
  full_name='proto.GetBillingDetailsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='at', full_name='proto.GetBillingDetailsReq.at', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=165,
)


_GETBILLINGDETAILSRESP = _descriptor.Descriptor(
  name='GetBillingDetailsResp',
  full_name='proto.GetBillingDetailsResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='periodStart', full_name='proto.GetBillingDetailsResp.periodStart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='periodEnd', full_name='proto.GetBillingDetailsResp.periodEnd', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalCost', full_name='proto.GetBillingDetailsResp.totalCost', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='documents', full_name='proto.GetBillingDetailsResp.documents', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search', full_name='proto.GetBillingDetailsResp.search', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traffic', full_name='proto.GetBillingDetailsResp.traffic', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billingFrequency', full_name='proto.GetBillingDetailsResp.billingFrequency', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\203\003\n\027*\025GetBillingDetailsResp2\347\002\022\344\002{\"periodStart\": \"2020-02-10T12:30:15.123Z\", \"periodEnd\": \"2020-02-29T23:59:59.999Z\", \"totalCost\": 800548.00, \"documents\": {\"cost\": 200.50, \"size\": 1000.4657}, \"search\": {\"cost\": 5.00, \"size\": 20.0}, \"traffic\": {\"cost\": 100.50, \"incoming\": 500.456, \"outgoing\": 200.564}, \"billingFrequency\": {\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=866,
)


_GETBILLINGFREQUENCYLISTREQ = _descriptor.Descriptor(
  name='GetBillingFrequencyListReq',
  full_name='proto.GetBillingFrequencyListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=896,
)


_GETBILLINGFREQUENCYLISTRESP = _descriptor.Descriptor(
  name='GetBillingFrequencyListResp',
  full_name='proto.GetBillingFrequencyListResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='billingFrequencyList', full_name='proto.GetBillingFrequencyListResp.billingFrequencyList', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\200\001\n\035*\033GetBillingFrequencyListResp2_\022]{\"billingFrequencyList\": [{\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}]}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=899,
  serialized_end=1118,
)


_SETNEXTBILLINGFREQUENCYREQ = _descriptor.Descriptor(
  name='SetNextBillingFrequencyReq',
  full_name='proto.SetNextBillingFrequencyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency', full_name='proto.SetNextBillingFrequencyReq.frequency', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='proto.SetNextBillingFrequencyReq.validFrom', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222Ac\n\034*\032SetNextBillingFrequencyReq2C\022A{\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1340,
)


_SETNEXTBILLINGFREQUENCYRESP = _descriptor.Descriptor(
  name='SetNextBillingFrequencyResp',
  full_name='proto.SetNextBillingFrequencyResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nextBillingFrequency', full_name='proto.SetNextBillingFrequencyResp.nextBillingFrequency', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A~\n\035*\033SetNextBillingFrequencyResp2]\022[{\"nextBillingFrequency\": {\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-02-10T12:30:15.123Z\"}}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1559,
)


_BILLINGFREQUENCY = _descriptor.Descriptor(
  name='BillingFrequency',
  full_name='proto.BillingFrequency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency', full_name='proto.BillingFrequency.frequency', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='proto.BillingFrequency.validFrom', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validTo', full_name='proto.BillingFrequency.validTo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\200\001\n\022*\020BillingFrequency2j\022h{\"frequency\": \"MONTHLY\", \"validFrom\": \"2020-03-01T00:00:15.123Z\", \"validTo\": \"2020-06-30T23:59:59.999Z\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1847,
)


_DOCUMENTCOSTS = _descriptor.Descriptor(
  name='DocumentCosts',
  full_name='proto.DocumentCosts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cost', full_name='proto.DocumentCosts.cost', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.DocumentCosts.size', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A9\n\020*\016DocumentsCosts2%\022#{\"cost\": 200.50, \"size\": 1000.4657}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1849,
  serialized_end=1954,
)


_SEARCHCOSTS = _descriptor.Descriptor(
  name='SearchCosts',
  full_name='proto.SearchCosts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cost', full_name='proto.SearchCosts.cost', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='proto.SearchCosts.size', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A/\n\r*\013SearchCosts2\036\022\034{\"cost\": 5.00, \"size\": 20.0}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1956,
  serialized_end=2049,
)


_TRAFFICCOSTS = _descriptor.Descriptor(
  name='TrafficCosts',
  full_name='proto.TrafficCosts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cost', full_name='proto.TrafficCosts.cost', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incoming', full_name='proto.TrafficCosts.incoming', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outgoing', full_name='proto.TrafficCosts.outgoing', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AN\n\016*\014TrafficCosts2<\022:{\"cost\": 100.50, \"incoming\": 500.456, \"outgoing\": 200.564}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2052,
  serialized_end=2199,
)


_PROCESSSUBSCRIPTIONEVENTREQ = _descriptor.Descriptor(
  name='ProcessSubscriptionEventReq',
  full_name='proto.ProcessSubscriptionEventReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ProcessSubscriptionEventReq.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customerIdentifier', full_name='proto.ProcessSubscriptionEventReq.customerIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\037\n\035*\033ProcessSubscriptionEventReq',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2201,
  serialized_end=2308,
)


_PROCESSSUBSCRIPTIONEVENTRESP = _descriptor.Descriptor(
  name='ProcessSubscriptionEventResp',
  full_name='proto.ProcessSubscriptionEventResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A \n\036*\034ProcessSubscriptionEventResp',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2310,
  serialized_end=2377,
)

_GETBILLINGDETAILSREQ.fields_by_name['at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETBILLINGDETAILSRESP.fields_by_name['periodStart'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETBILLINGDETAILSRESP.fields_by_name['periodEnd'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETBILLINGDETAILSRESP.fields_by_name['documents'].message_type = _DOCUMENTCOSTS
_GETBILLINGDETAILSRESP.fields_by_name['search'].message_type = _SEARCHCOSTS
_GETBILLINGDETAILSRESP.fields_by_name['traffic'].message_type = _TRAFFICCOSTS
_GETBILLINGDETAILSRESP.fields_by_name['billingFrequency'].message_type = _BILLINGFREQUENCY
_GETBILLINGFREQUENCYLISTRESP.fields_by_name['billingFrequencyList'].message_type = _BILLINGFREQUENCY
_SETNEXTBILLINGFREQUENCYREQ.fields_by_name['frequency'].enum_type = _TIMEINTERVAL
_SETNEXTBILLINGFREQUENCYREQ.fields_by_name['validFrom'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETNEXTBILLINGFREQUENCYRESP.fields_by_name['nextBillingFrequency'].message_type = _BILLINGFREQUENCY
_BILLINGFREQUENCY.fields_by_name['frequency'].enum_type = _TIMEINTERVAL
_BILLINGFREQUENCY.fields_by_name['validFrom'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BILLINGFREQUENCY.fields_by_name['validTo'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['GetBillingDetailsReq'] = _GETBILLINGDETAILSREQ
DESCRIPTOR.message_types_by_name['GetBillingDetailsResp'] = _GETBILLINGDETAILSRESP
DESCRIPTOR.message_types_by_name['GetBillingFrequencyListReq'] = _GETBILLINGFREQUENCYLISTREQ
DESCRIPTOR.message_types_by_name['GetBillingFrequencyListResp'] = _GETBILLINGFREQUENCYLISTRESP
DESCRIPTOR.message_types_by_name['SetNextBillingFrequencyReq'] = _SETNEXTBILLINGFREQUENCYREQ
DESCRIPTOR.message_types_by_name['SetNextBillingFrequencyResp'] = _SETNEXTBILLINGFREQUENCYRESP
DESCRIPTOR.message_types_by_name['BillingFrequency'] = _BILLINGFREQUENCY
DESCRIPTOR.message_types_by_name['DocumentCosts'] = _DOCUMENTCOSTS
DESCRIPTOR.message_types_by_name['SearchCosts'] = _SEARCHCOSTS
DESCRIPTOR.message_types_by_name['TrafficCosts'] = _TRAFFICCOSTS
DESCRIPTOR.message_types_by_name['ProcessSubscriptionEventReq'] = _PROCESSSUBSCRIPTIONEVENTREQ
DESCRIPTOR.message_types_by_name['ProcessSubscriptionEventResp'] = _PROCESSSUBSCRIPTIONEVENTRESP
DESCRIPTOR.enum_types_by_name['TimeInterval'] = _TIMEINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBillingDetailsReq = _reflection.GeneratedProtocolMessageType('GetBillingDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETBILLINGDETAILSREQ,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.GetBillingDetailsReq)
  })
_sym_db.RegisterMessage(GetBillingDetailsReq)

GetBillingDetailsResp = _reflection.GeneratedProtocolMessageType('GetBillingDetailsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETBILLINGDETAILSRESP,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.GetBillingDetailsResp)
  })
_sym_db.RegisterMessage(GetBillingDetailsResp)

GetBillingFrequencyListReq = _reflection.GeneratedProtocolMessageType('GetBillingFrequencyListReq', (_message.Message,), {
  'DESCRIPTOR' : _GETBILLINGFREQUENCYLISTREQ,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.GetBillingFrequencyListReq)
  })
_sym_db.RegisterMessage(GetBillingFrequencyListReq)

GetBillingFrequencyListResp = _reflection.GeneratedProtocolMessageType('GetBillingFrequencyListResp', (_message.Message,), {
  'DESCRIPTOR' : _GETBILLINGFREQUENCYLISTRESP,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.GetBillingFrequencyListResp)
  })
_sym_db.RegisterMessage(GetBillingFrequencyListResp)

SetNextBillingFrequencyReq = _reflection.GeneratedProtocolMessageType('SetNextBillingFrequencyReq', (_message.Message,), {
  'DESCRIPTOR' : _SETNEXTBILLINGFREQUENCYREQ,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.SetNextBillingFrequencyReq)
  })
_sym_db.RegisterMessage(SetNextBillingFrequencyReq)

SetNextBillingFrequencyResp = _reflection.GeneratedProtocolMessageType('SetNextBillingFrequencyResp', (_message.Message,), {
  'DESCRIPTOR' : _SETNEXTBILLINGFREQUENCYRESP,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.SetNextBillingFrequencyResp)
  })
_sym_db.RegisterMessage(SetNextBillingFrequencyResp)

BillingFrequency = _reflection.GeneratedProtocolMessageType('BillingFrequency', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGFREQUENCY,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.BillingFrequency)
  })
_sym_db.RegisterMessage(BillingFrequency)

DocumentCosts = _reflection.GeneratedProtocolMessageType('DocumentCosts', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTCOSTS,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.DocumentCosts)
  })
_sym_db.RegisterMessage(DocumentCosts)

SearchCosts = _reflection.GeneratedProtocolMessageType('SearchCosts', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHCOSTS,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.SearchCosts)
  })
_sym_db.RegisterMessage(SearchCosts)

TrafficCosts = _reflection.GeneratedProtocolMessageType('TrafficCosts', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICCOSTS,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.TrafficCosts)
  })
_sym_db.RegisterMessage(TrafficCosts)

ProcessSubscriptionEventReq = _reflection.GeneratedProtocolMessageType('ProcessSubscriptionEventReq', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSSUBSCRIPTIONEVENTREQ,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.ProcessSubscriptionEventReq)
  })
_sym_db.RegisterMessage(ProcessSubscriptionEventReq)

ProcessSubscriptionEventResp = _reflection.GeneratedProtocolMessageType('ProcessSubscriptionEventResp', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSSUBSCRIPTIONEVENTRESP,
  '__module__' : 'billing_pb2'
  # @@protoc_insertion_point(class_scope:proto.ProcessSubscriptionEventResp)
  })
_sym_db.RegisterMessage(ProcessSubscriptionEventResp)


DESCRIPTOR._options = None
_GETBILLINGDETAILSRESP._options = None
_GETBILLINGFREQUENCYLISTRESP._options = None
_SETNEXTBILLINGFREQUENCYREQ._options = None
_SETNEXTBILLINGFREQUENCYRESP._options = None
_BILLINGFREQUENCY._options = None
_DOCUMENTCOSTS._options = None
_SEARCHCOSTS._options = None
_TRAFFICCOSTS._options = None
_PROCESSSUBSCRIPTIONEVENTREQ._options = None
_PROCESSSUBSCRIPTIONEVENTRESP._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strongdoc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2
import strongdoc.proto.document_pb2 as document__pb2
import strongdoc.proto.documentNoStore_pb2 as documentNoStore__pb2
import strongdoc.proto.search_pb2 as search__pb2
import strongdoc.proto.accounts_pb2 as accounts__pb2
import strongdoc.proto.billing_pb2 as billing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strongdoc.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\016StrongDocProto\210\001\001\222A\265\002\0227\n\rStrongDoc API\"!\n\nStrongSalt\032\023info@strongsalt.com2\0031.02\020application/json:\020application/jsonZ\212\001\n\207\001\n\nApiKeyAuth\022y\010\002\022dThe word \'Bearer\' and a space is required before the token.\nFor example,\nBearer authentication_token\032\rAuthorization \002rI\n\027More about gRPC-Gateway\022.https://github.com/grpc-ecosystem/grpc-gateway',
  serialized_pb=b'\n\x0fstrongdoc.proto\x12\x05proto\x1a\x1cgoogle/api/annotations.proto\x1a,protoc-gen-swagger/options/annotations.proto\x1a\x0e\x64ocument.proto\x1a\x15\x64ocumentNoStore.proto\x1a\x0csearch.proto\x1a\x0e\x61\x63\x63ounts.proto\x1a\rbilling.proto\"\x15\n\x13GetConfigurationReq\"-\n\x14GetConfigurationResp\x12\x15\n\rconfiguration\x18\x01 \x01(\t2\x8c\x1d\n\x10StrongDocService\x12\x8c\x01\n\x14RegisterOrganization\x12\".proto.RegisterOrganizationRequest\x1a#.proto.RegisterOrganizationResponse\"+\x82\xd3\xe4\x93\x02%\" /v1/account/registerOrganization:\x01*\x12\x9e\x01\n\x12RemoveOrganization\x12 .proto.RemoveOrganizationRequest\x1a!.proto.RemoveOrganizationResponse\"C\x82\xd3\xe4\x93\x02(*&/v1/account/removeOrganization/{force}\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x81\x01\n\x0cRegisterUser\x12\x1a.proto.RegisterUserRequest\x1a\x1b.proto.RegisterUserResponse\"8\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/account/registerUser:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12r\n\tListUsers\x12\x17.proto.ListUsersRequest\x1a\x18.proto.ListUsersResponse\"2\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/account/listUsers\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12y\n\nRemoveUser\x12\x18.proto.RemoveUserRequest\x1a\x19.proto.RemoveUserResponse\"6\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/account/removeUser:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12}\n\x0bPromoteUser\x12\x19.proto.PromoteUserRequest\x1a\x1a.proto.PromoteUserResponse\"7\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/account/promoteUser:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12y\n\nDemoteUser\x12\x18.proto.DemoteUserRequest\x1a\x19.proto.DemoteUserResponse\"6\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/account/demoteUser:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12y\n\rListDocuments\x12\x1b.proto.ListDocumentsRequest\x1a\x1c.proto.ListDocumentsResponse\"-\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/doc/listDocs\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x82\x01\n\x0eRemoveDocument\x12\x1c.proto.RemoveDocumentRequest\x1a\x1d.proto.RemoveDocumentResponse\"3\x82\xd3\xe4\x93\x02\x18*\x16/v1/doc/remove/{docID}\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12Q\n\x14UploadDocumentStream\x12\x19.proto.UploadDocStreamReq\x1a\x1a.proto.UploadDocStreamResp\"\x00(\x01\x12k\n\x0eUploadDocument\x12\x13.proto.UploadDocReq\x1a\x14.proto.UploadDocResp\".\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/doc/upload:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12W\n\x16\x44ownloadDocumentStream\x12\x1b.proto.DownloadDocStreamReq\x1a\x1c.proto.DownloadDocStreamResp\"\x00\x30\x01\x12x\n\x10\x44ownloadDocument\x12\x15.proto.DownloadDocReq\x1a\x16.proto.DownloadDocResp\"5\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/doc/download/{docID}\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12V\n\x15\x45ncryptDocumentStream\x12\x1a.proto.EncryptDocStreamReq\x1a\x1b.proto.EncryptDocStreamResp\"\x00(\x01\x30\x01\x12o\n\x0f\x45ncryptDocument\x12\x14.proto.EncryptDocReq\x1a\x15.proto.EncryptDocResp\"/\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/doc/encrypt:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12V\n\x15\x44\x65\x63ryptDocumentStream\x12\x1a.proto.DecryptDocStreamReq\x1a\x1b.proto.DecryptDocStreamResp\"\x00(\x01\x30\x01\x12t\n\x0f\x44\x65\x63ryptDocument\x12\x14.proto.DecryptDocReq\x1a\x15.proto.DecryptDocResp\"4\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/doc/decrypt/{docID}\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12|\n\rShareDocument\x12\x1b.proto.ShareDocumentRequest\x1a\x1c.proto.ShareDocumentResponse\"0\x82\xd3\xe4\x93\x02\x15\"\x10/v1/doc/shareDoc:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x84\x01\n\x0fUnshareDocument\x12\x1d.proto.UnshareDocumentRequest\x1a\x1e.proto.UnshareDocumentResponse\"2\x82\xd3\xe4\x93\x02\x17\"\x12/v1/doc/unshareDoc:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12M\n\x05Login\x12\x13.proto.LoginRequest\x1a\x14.proto.LoginResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/auth/login:\x01*\x12^\n\x06Logout\x12\x14.proto.LogoutRequest\x1a\x15.proto.LogoutResponse\"\'\x82\xd3\xe4\x93\x02\x0c\"\n/v1/logout\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12j\n\x06Search\x12\x14.proto.SearchRequest\x1a\x15.proto.SearchResponse\"3\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/doc/search/{query}\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x89\x01\n\x0e\x41\x64\x64SharableOrg\x12\x1c.proto.AddSharableOrgRequest\x1a\x1d.proto.AddSharableOrgResponse\":\x82\xd3\xe4\x93\x02\x1f\x32\x1a/v1/account/addSharableOrg:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x95\x01\n\x11RemoveSharableOrg\x12\x1f.proto.RemoveSharableOrgRequest\x1a .proto.RemoveSharableOrgResponse\"=\x82\xd3\xe4\x93\x02\"2\x1d/v1/account/removeSharableOrg:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\xa1\x01\n\x14SetMultiLevelSharing\x12\".proto.SetMultiLevelSharingRequest\x1a#.proto.SetMultiLevelSharingResponse\"@\x82\xd3\xe4\x93\x02%\x1a /v1/account/setMultiLevelSharing:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x80\x01\n\x11GetBillingDetails\x12\x1b.proto.GetBillingDetailsReq\x1a\x1c.proto.GetBillingDetailsResp\"0\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/account/billing\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x9c\x01\n\x17GetBillingFrequencyList\x12!.proto.GetBillingFrequencyListReq\x1a\".proto.GetBillingFrequencyListResp\":\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/account/billing/frequency\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x9f\x01\n\x17SetNextBillingFrequency\x12!.proto.SetNextBillingFrequencyReq\x1a\".proto.SetNextBillingFrequencyResp\"=\x82\xd3\xe4\x93\x02\"\x1a\x1d/v1/account/billing/frequency:\x01*\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12{\n\x10GetConfiguration\x12\x1a.proto.GetConfigurationReq\x1a\x1b.proto.GetConfigurationResp\".\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/configuration\x92\x41\x12\x62\x10\n\x0e\n\nApiKeyAuth\x12\x00\x12\x87\x01\n\x18ProcessSubscriptionEvent\x12\".proto.ProcessSubscriptionEventReq\x1a#.proto.ProcessSubscriptionEventResp\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/subscriptionWebhook:\x01*B\xf0\x02\n\"com.strongsalt.strongdoc.sdk.protoB\x0eStrongDocProto\x88\x01\x01\x92\x41\xb5\x02\x12\x37\n\rStrongDoc API\"!\n\nStrongSalt\x1a\x13info@strongsalt.com2\x03\x31.02\x10\x61pplication/json:\x10\x61pplication/jsonZ\x8a\x01\n\x87\x01\n\nApiKeyAuth\x12y\x08\x02\x12\x64The word \'Bearer\' and a space is required before the token.\nFor example,\nBearer authentication_token\x1a\rAuthorization \x02rI\n\x17More about gRPC-Gateway\x12.https://github.com/grpc-ecosystem/grpc-gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,document__pb2.DESCRIPTOR,documentNoStore__pb2.DESCRIPTOR,search__pb2.DESCRIPTOR,accounts__pb2.DESCRIPTOR,billing__pb2.DESCRIPTOR,])




_GETCONFIGURATIONREQ = _descriptor.Descriptor(
  name='GetConfigurationReq',
  full_name='proto.GetConfigurationReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=207,
)


_GETCONFIGURATIONRESP = _descriptor.Descriptor(
  name='GetConfigurationResp',
  full_name='proto.GetConfigurationResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration', full_name='proto.GetConfigurationResp.configuration', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=254,
)

DESCRIPTOR.message_types_by_name['GetConfigurationReq'] = _GETCONFIGURATIONREQ
DESCRIPTOR.message_types_by_name['GetConfigurationResp'] = _GETCONFIGURATIONRESP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetConfigurationReq = _reflection.GeneratedProtocolMessageType('GetConfigurationReq', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONREQ,
  '__module__' : 'strongdoc_pb2'
  # @@protoc_insertion_point(class_scope:proto.GetConfigurationReq)
  })
_sym_db.RegisterMessage(GetConfigurationReq)

GetConfigurationResp = _reflection.GeneratedProtocolMessageType('GetConfigurationResp', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONRESP,
  '__module__' : 'strongdoc_pb2'
  # @@protoc_insertion_point(class_scope:proto.GetConfigurationResp)
  })
_sym_db.RegisterMessage(GetConfigurationResp)


DESCRIPTOR._options = None

_STRONGDOCSERVICE = _descriptor.ServiceDescriptor(
  name='StrongDocService',
  full_name='proto.StrongDocService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=257,
  serialized_end=3981,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterOrganization',
    full_name='proto.StrongDocService.RegisterOrganization',
    index=0,
    containing_service=None,
    input_type=accounts__pb2._REGISTERORGANIZATIONREQUEST,
    output_type=accounts__pb2._REGISTERORGANIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002%\" /v1/account/registerOrganization:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='RemoveOrganization',
    full_name='proto.StrongDocService.RemoveOrganization',
    index=1,
    containing_service=None,
    input_type=accounts__pb2._REMOVEORGANIZATIONREQUEST,
    output_type=accounts__pb2._REMOVEORGANIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002(*&/v1/account/removeOrganization/{force}\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='RegisterUser',
    full_name='proto.StrongDocService.RegisterUser',
    index=2,
    containing_service=None,
    input_type=accounts__pb2._REGISTERUSERREQUEST,
    output_type=accounts__pb2._REGISTERUSERRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\030/v1/account/registerUser:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='ListUsers',
    full_name='proto.StrongDocService.ListUsers',
    index=3,
    containing_service=None,
    input_type=accounts__pb2._LISTUSERSREQUEST,
    output_type=accounts__pb2._LISTUSERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/account/listUsers\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='RemoveUser',
    full_name='proto.StrongDocService.RemoveUser',
    index=4,
    containing_service=None,
    input_type=accounts__pb2._REMOVEUSERREQUEST,
    output_type=accounts__pb2._REMOVEUSERRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\026/v1/account/removeUser:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='PromoteUser',
    full_name='proto.StrongDocService.PromoteUser',
    index=5,
    containing_service=None,
    input_type=accounts__pb2._PROMOTEUSERREQUEST,
    output_type=accounts__pb2._PROMOTEUSERRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\027/v1/account/promoteUser:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='DemoteUser',
    full_name='proto.StrongDocService.DemoteUser',
    index=6,
    containing_service=None,
    input_type=accounts__pb2._DEMOTEUSERREQUEST,
    output_type=accounts__pb2._DEMOTEUSERRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\026/v1/account/demoteUser:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='ListDocuments',
    full_name='proto.StrongDocService.ListDocuments',
    index=7,
    containing_service=None,
    input_type=document__pb2._LISTDOCUMENTSREQUEST,
    output_type=document__pb2._LISTDOCUMENTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/v1/doc/listDocs\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='RemoveDocument',
    full_name='proto.StrongDocService.RemoveDocument',
    index=8,
    containing_service=None,
    input_type=document__pb2._REMOVEDOCUMENTREQUEST,
    output_type=document__pb2._REMOVEDOCUMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/doc/remove/{docID}\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='UploadDocumentStream',
    full_name='proto.StrongDocService.UploadDocumentStream',
    index=9,
    containing_service=None,
    input_type=document__pb2._UPLOADDOCSTREAMREQ,
    output_type=document__pb2._UPLOADDOCSTREAMRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UploadDocument',
    full_name='proto.StrongDocService.UploadDocument',
    index=10,
    containing_service=None,
    input_type=document__pb2._UPLOADDOCREQ,
    output_type=document__pb2._UPLOADDOCRESP,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/doc/upload:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='DownloadDocumentStream',
    full_name='proto.StrongDocService.DownloadDocumentStream',
    index=11,
    containing_service=None,
    input_type=document__pb2._DOWNLOADDOCSTREAMREQ,
    output_type=document__pb2._DOWNLOADDOCSTREAMRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadDocument',
    full_name='proto.StrongDocService.DownloadDocument',
    index=12,
    containing_service=None,
    input_type=document__pb2._DOWNLOADDOCREQ,
    output_type=document__pb2._DOWNLOADDOCRESP,
    serialized_options=b'\202\323\344\223\002\032\022\030/v1/doc/download/{docID}\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='EncryptDocumentStream',
    full_name='proto.StrongDocService.EncryptDocumentStream',
    index=13,
    containing_service=None,
    input_type=documentNoStore__pb2._ENCRYPTDOCSTREAMREQ,
    output_type=documentNoStore__pb2._ENCRYPTDOCSTREAMRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EncryptDocument',
    full_name='proto.StrongDocService.EncryptDocument',
    index=14,
    containing_service=None,
    input_type=documentNoStore__pb2._ENCRYPTDOCREQ,
    output_type=documentNoStore__pb2._ENCRYPTDOCRESP,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/doc/encrypt:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='DecryptDocumentStream',
    full_name='proto.StrongDocService.DecryptDocumentStream',
    index=15,
    containing_service=None,
    input_type=documentNoStore__pb2._DECRYPTDOCSTREAMREQ,
    output_type=documentNoStore__pb2._DECRYPTDOCSTREAMRESP,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DecryptDocument',
    full_name='proto.StrongDocService.DecryptDocument',
    index=16,
    containing_service=None,
    input_type=documentNoStore__pb2._DECRYPTDOCREQ,
    output_type=documentNoStore__pb2._DECRYPTDOCRESP,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/doc/decrypt/{docID}\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='ShareDocument',
    full_name='proto.StrongDocService.ShareDocument',
    index=17,
    containing_service=None,
    input_type=document__pb2._SHAREDOCUMENTREQUEST,
    output_type=document__pb2._SHAREDOCUMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\"\020/v1/doc/shareDoc:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='UnshareDocument',
    full_name='proto.StrongDocService.UnshareDocument',
    index=18,
    containing_service=None,
    input_type=document__pb2._UNSHAREDOCUMENTREQUEST,
    output_type=document__pb2._UNSHAREDOCUMENTRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/doc/unshareDoc:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='proto.StrongDocService.Login',
    index=19,
    containing_service=None,
    input_type=accounts__pb2._LOGINREQUEST,
    output_type=accounts__pb2._LOGINRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/auth/login:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='Logout',
    full_name='proto.StrongDocService.Logout',
    index=20,
    containing_service=None,
    input_type=accounts__pb2._LOGOUTREQUEST,
    output_type=accounts__pb2._LOGOUTRESPONSE,
    serialized_options=b'\202\323\344\223\002\014\"\n/v1/logout\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='proto.StrongDocService.Search',
    index=21,
    containing_service=None,
    input_type=search__pb2._SEARCHREQUEST,
    output_type=search__pb2._SEARCHRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/doc/search/{query}\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='AddSharableOrg',
    full_name='proto.StrongDocService.AddSharableOrg',
    index=22,
    containing_service=None,
    input_type=accounts__pb2._ADDSHARABLEORGREQUEST,
    output_type=accounts__pb2._ADDSHARABLEORGRESPONSE,
    serialized_options=b'\202\323\344\223\002\0372\032/v1/account/addSharableOrg:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='RemoveSharableOrg',
    full_name='proto.StrongDocService.RemoveSharableOrg',
    index=23,
    containing_service=None,
    input_type=accounts__pb2._REMOVESHARABLEORGREQUEST,
    output_type=accounts__pb2._REMOVESHARABLEORGRESPONSE,
    serialized_options=b'\202\323\344\223\002\"2\035/v1/account/removeSharableOrg:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='SetMultiLevelSharing',
    full_name='proto.StrongDocService.SetMultiLevelSharing',
    index=24,
    containing_service=None,
    input_type=accounts__pb2._SETMULTILEVELSHARINGREQUEST,
    output_type=accounts__pb2._SETMULTILEVELSHARINGRESPONSE,
    serialized_options=b'\202\323\344\223\002%\032 /v1/account/setMultiLevelSharing:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='GetBillingDetails',
    full_name='proto.StrongDocService.GetBillingDetails',
    index=25,
    containing_service=None,
    input_type=billing__pb2._GETBILLINGDETAILSREQ,
    output_type=billing__pb2._GETBILLINGDETAILSRESP,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/account/billing\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='GetBillingFrequencyList',
    full_name='proto.StrongDocService.GetBillingFrequencyList',
    index=26,
    containing_service=None,
    input_type=billing__pb2._GETBILLINGFREQUENCYLISTREQ,
    output_type=billing__pb2._GETBILLINGFREQUENCYLISTRESP,
    serialized_options=b'\202\323\344\223\002\037\022\035/v1/account/billing/frequency\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='SetNextBillingFrequency',
    full_name='proto.StrongDocService.SetNextBillingFrequency',
    index=27,
    containing_service=None,
    input_type=billing__pb2._SETNEXTBILLINGFREQUENCYREQ,
    output_type=billing__pb2._SETNEXTBILLINGFREQUENCYRESP,
    serialized_options=b'\202\323\344\223\002\"\032\035/v1/account/billing/frequency:\001*\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='GetConfiguration',
    full_name='proto.StrongDocService.GetConfiguration',
    index=28,
    containing_service=None,
    input_type=_GETCONFIGURATIONREQ,
    output_type=_GETCONFIGURATIONRESP,
    serialized_options=b'\202\323\344\223\002\023\022\021/v1/configuration\222A\022b\020\n\016\n\nApiKeyAuth\022\000',
  ),
  _descriptor.MethodDescriptor(
    name='ProcessSubscriptionEvent',
    full_name='proto.StrongDocService.ProcessSubscriptionEvent',
    index=29,
    containing_service=None,
    input_type=billing__pb2._PROCESSSUBSCRIPTIONEVENTREQ,
    output_type=billing__pb2._PROCESSSUBSCRIPTIONEVENTRESP,
    serialized_options=b'\202\323\344\223\002\034\"\027/v1/subscriptionWebhook:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_STRONGDOCSERVICE)

DESCRIPTOR.services_by_name['StrongDocService'] = _STRONGDOCSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: accounts.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strongdoc.proto.protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='accounts.proto',
  package='proto',
  syntax='proto3',
  serialized_options=b'\n\"com.strongsalt.strongdoc.sdk.protoB\007Account\210\001\001',
  serialized_pb=b'\n\x0e\x61\x63\x63ounts.proto\x12\x05proto\x1a,protoc-gen-swagger/options/annotations.proto\"\xb6\x04\n\x1bRegisterOrganizationRequest\x12\x0f\n\x07orgName\x18\x01 \x01(\t\x12\x0f\n\x07orgAddr\x18\x02 \x01(\t\x12\x10\n\x08userName\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x14\n\x0csharableOrgs\x18\x06 \x03(\t\x12\x17\n\x0fmultiLevelShare\x18\x07 \x01(\x08\x12\x0e\n\x06source\x18\x08 \x01(\t\x12\x12\n\nsourceData\x18\t \x01(\t:\xee\x02\x92\x41\xea\x02\n\x1d*\x1bRegisterOrganizationRequest2\xc8\x02\x12\xc5\x02{\"orgName\": \"WhiteHouse\", \"orgAddr\": \"1600 Pennsylvania Ave NW, Washington, DC 20500\", \"userName\": \"Donald Trump\", \"password\": \"ukrainismyfriend\", \"email\": \"donald.trump@whitehouse.gov\", \"sharableOrgs\": [\"cnn\", \"fbi\", \"democrats\"], \"multiLevelShare\": true, \"source\": \"\", \"sourceData\": \"{\\\"registrationToken\\\": \\\"abcd1234\\\"}\"}\"\xa6\x01\n\x1cRegisterOrganizationResponse\x12\r\n\x05orgID\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t:g\x92\x41\x64\n\x1e*\x1cRegisterOrganizationResponse2B\x12@{\"orgID\": \"WhiteHouse\", \"userID\": \"donald.trump@whitehouse.gov\"}\"\xeb\x01\n\x13RegisterUserRequest\x12\x10\n\x08userName\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\r\n\x05\x61\x64min\x18\x04 \x01(\x08:\x91\x01\x92\x41\x8d\x01\n\x15*\x13RegisterUserRequest2t\x12r{\"userName\": \"Mike Pence\", \"password\": \"donaldismyfriend\", \"email\": \"mike.pence@whitehouse.gov\", \"admin\": \"false\"}\"n\n\x14RegisterUserResponse\x12\x0e\n\x06userID\x18\x01 \x01(\t:F\x92\x41\x43\n\x16*\x14RegisterUserResponse2)\x12\'{\"userID\": \"mike.pence@whitehouse.gov\"}\"i\n\x11RemoveUserRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t:D\x92\x41\x41\n\x13*\x11RemoveUserRequest2*\x12({\"userID\": \"donal.trump@whitehouse.gov\"}\"N\n\x12RemoveUserResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x03:)\x92\x41&\n\x14*\x12RemoveUserResponse2\x0e\x12\x0c{\"count\": 1}\"k\n\x12PromoteUserRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t:E\x92\x41\x42\n\x14*\x12PromoteUserRequest2*\x12({\"userID\": \"donald.duck@whitehouse.gov\"}\"V\n\x13PromoteUserResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:.\x92\x41+\n\x14*\x12PromoteUserRequest2\x13\x12\x11{\"success\": true}\"j\n\x11\x44\x65moteUserRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t:E\x92\x41\x42\n\x13*\x11\x44\x65moteUserRequest2+\x12){\"userID\": \"donald.trump@whitehouse.gov\"}\"U\n\x12\x44\x65moteUserResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:.\x92\x41+\n\x14*\x12\x44\x65moteUserResponse2\x13\x12\x11{\"success\": true}\"\xbd\x01\n\x0cLoginRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05orgID\x18\x03 \x01(\t:|\x92\x41y\n\x0e*\x0cLoginRequest2g\x12\x65{\"userID\": \"donald.trump@whitehouse.gov\", \"password\": \"makeamericagreatagain\", \"orgID\": \"WhiteHouse\"}\"Q\n\rLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t:1\x92\x41.\n\x0f*\rLoginResponse2\x1b\x12\x19{\"token\": \"blahblahblah\"}\"%\n\rLogoutRequest:\x14\x92\x41\x11\n\x0f*\rLogoutRequest\"P\n\x0eLogoutResponse\x12\x0e\n\x06status\x18\x01 \x01(\t:.\x92\x41+\n\x10*\x0eLogoutResponse2\x17\x12\x15{\"status\": \"you OUT\"}\"+\n\x10ListUsersRequest:\x17\x92\x41\x14\n\x12*\x10ListUsersRequest\"\x89\x02\n\x11ListUsersResponse\x12\x32\n\x08orgUsers\x18\x01 \x03(\x0b\x32 .proto.ListUsersResponse.OrgUser\x1a<\n\x07OrgUser\x12\x10\n\x08userName\x18\x01 \x01(\t\x12\x0e\n\x06userID\x18\x02 \x01(\t\x12\x0f\n\x07isAdmin\x18\x03 \x01(\x08:\x81\x01\x92\x41~\n\x13*\x11ListUsersResponse2g\x12\x65{\"orgUsers\":[{\"userName\": \"Donald Trump\", \"userID\": \"donald.trump@whitehouse.gov\", \"isAdmin\": true}]}\"_\n\x19RemoveOrganizationRequest\x12\r\n\x05\x66orce\x18\x01 \x01(\x08:3\x92\x41\x30\n\x1b*\x19RemoveOrganizationRequest2\x11\x12\x0f{\"force\": true}\"e\n\x1aRemoveOrganizationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:6\x92\x41\x33\n\x1c*\x1aRemoveOrganizationResponse2\x13\x12\x11{\"success\": true}\"a\n\x15\x41\x64\x64SharableOrgRequest\x12\x10\n\x08newOrgID\x18\x01 \x01(\t:6\x92\x41\x33\n\x17*\x15\x41\x64\x64SharableOrgRequest2\x18\x12\x16{\"newOrgID\": \"string\"}\"]\n\x16\x41\x64\x64SharableOrgResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:2\x92\x41/\n\x18*\x16\x41\x64\x64SharableOrgResponse2\x13\x12\x11{\"success\": true}\"m\n\x18RemoveSharableOrgRequest\x12\x13\n\x0bremoveOrgID\x18\x01 \x01(\t:<\x92\x41\x39\n\x1a*\x18RemoveSharableOrgRequest2\x1b\x12\x19{\"removeOrgID\": \"string\"}\"c\n\x19RemoveSharableOrgResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:5\x92\x41\x32\n\x1b*\x19RemoveSharableOrgResponse2\x13\x12\x11{\"success\": true}\"e\n\x1bSetMultiLevelSharingRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08:6\x92\x41\x33\n\x1d*\x1bSetMultiLevelSharingRequest2\x12\x12\x10{\"enable\": true}\"i\n\x1cSetMultiLevelSharingResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08:8\x92\x41\x35\n\x1e*\x1cSetMultiLevelSharingResponse2\x13\x12\x11{\"success\": true}B0\n\"com.strongsalt.strongdoc.sdk.protoB\x07\x41\x63\x63ount\x88\x01\x01\x62\x06proto3'
  ,
  dependencies=[protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_REGISTERORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='RegisterOrganizationRequest',
  full_name='proto.RegisterOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgName', full_name='proto.RegisterOrganizationRequest.orgName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orgAddr', full_name='proto.RegisterOrganizationRequest.orgAddr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userName', full_name='proto.RegisterOrganizationRequest.userName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='proto.RegisterOrganizationRequest.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='proto.RegisterOrganizationRequest.email', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sharableOrgs', full_name='proto.RegisterOrganizationRequest.sharableOrgs', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multiLevelShare', full_name='proto.RegisterOrganizationRequest.multiLevelShare', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='proto.RegisterOrganizationRequest.source', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sourceData', full_name='proto.RegisterOrganizationRequest.sourceData', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\352\002\n\035*\033RegisterOrganizationRequest2\310\002\022\305\002{\"orgName\": \"WhiteHouse\", \"orgAddr\": \"1600 Pennsylvania Ave NW, Washington, DC 20500\", \"userName\": \"Donald Trump\", \"password\": \"ukrainismyfriend\", \"email\": \"donald.trump@whitehouse.gov\", \"sharableOrgs\": [\"cnn\", \"fbi\", \"democrats\"], \"multiLevelShare\": true, \"source\": \"\", \"sourceData\": \"{\\\"registrationToken\\\": \\\"abcd1234\\\"}\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=638,
)


_REGISTERORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='RegisterOrganizationResponse',
  full_name='proto.RegisterOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgID', full_name='proto.RegisterOrganizationResponse.orgID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.RegisterOrganizationResponse.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222Ad\n\036*\034RegisterOrganizationResponse2B\022@{\"orgID\": \"WhiteHouse\", \"userID\": \"donald.trump@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=807,
)


_REGISTERUSERREQUEST = _descriptor.Descriptor(
  name='RegisterUserRequest',
  full_name='proto.RegisterUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userName', full_name='proto.RegisterUserRequest.userName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='proto.RegisterUserRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email', full_name='proto.RegisterUserRequest.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='admin', full_name='proto.RegisterUserRequest.admin', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\215\001\n\025*\023RegisterUserRequest2t\022r{\"userName\": \"Mike Pence\", \"password\": \"donaldismyfriend\", \"email\": \"mike.pence@whitehouse.gov\", \"admin\": \"false\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=1045,
)


_REGISTERUSERRESPONSE = _descriptor.Descriptor(
  name='RegisterUserResponse',
  full_name='proto.RegisterUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.RegisterUserResponse.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AC\n\026*\024RegisterUserResponse2)\022\'{\"userID\": \"mike.pence@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1157,
)


_REMOVEUSERREQUEST = _descriptor.Descriptor(
  name='RemoveUserRequest',
  full_name='proto.RemoveUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.RemoveUserRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AA\n\023*\021RemoveUserRequest2*\022({\"userID\": \"donal.trump@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1159,
  serialized_end=1264,
)


_REMOVEUSERRESPONSE = _descriptor.Descriptor(
  name='RemoveUserResponse',
  full_name='proto.RemoveUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='proto.RemoveUserResponse.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A&\n\024*\022RemoveUserResponse2\016\022\014{\"count\": 1}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1344,
)


_PROMOTEUSERREQUEST = _descriptor.Descriptor(
  name='PromoteUserRequest',
  full_name='proto.PromoteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.PromoteUserRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AB\n\024*\022PromoteUserRequest2*\022({\"userID\": \"donald.duck@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1453,
)


_PROMOTEUSERRESPONSE = _descriptor.Descriptor(
  name='PromoteUserResponse',
  full_name='proto.PromoteUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.PromoteUserResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\024*\022PromoteUserRequest2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1455,
  serialized_end=1541,
)


_DEMOTEUSERREQUEST = _descriptor.Descriptor(
  name='DemoteUserRequest',
  full_name='proto.DemoteUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.DemoteUserRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222AB\n\023*\021DemoteUserRequest2+\022){\"userID\": \"donald.trump@whitehouse.gov\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1543,
  serialized_end=1649,
)


_DEMOTEUSERRESPONSE = _descriptor.Descriptor(
  name='DemoteUserResponse',
  full_name='proto.DemoteUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.DemoteUserResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\024*\022DemoteUserResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1651,
  serialized_end=1736,
)


_LOGINREQUEST = _descriptor.Descriptor(
  name='LoginRequest',
  full_name='proto.LoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.LoginRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='proto.LoginRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orgID', full_name='proto.LoginRequest.orgID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222Ay\n\016*\014LoginRequest2g\022e{\"userID\": \"donald.trump@whitehouse.gov\", \"password\": \"makeamericagreatagain\", \"orgID\": \"WhiteHouse\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1739,
  serialized_end=1928,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='proto.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.LoginResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A.\n\017*\rLoginResponse2\033\022\031{\"token\": \"blahblahblah\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1930,
  serialized_end=2011,
)


_LOGOUTREQUEST = _descriptor.Descriptor(
  name='LogoutRequest',
  full_name='proto.LogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\021\n\017*\rLogoutRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2013,
  serialized_end=2050,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='proto.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.LogoutResponse.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A+\n\020*\016LogoutResponse2\027\022\025{\"status\": \"you OUT\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2052,
  serialized_end=2132,
)


_LISTUSERSREQUEST = _descriptor.Descriptor(
  name='ListUsersRequest',
  full_name='proto.ListUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\024\n\022*\020ListUsersRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2134,
  serialized_end=2177,
)


_LISTUSERSRESPONSE_ORGUSER = _descriptor.Descriptor(
  name='OrgUser',
  full_name='proto.ListUsersResponse.OrgUser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userName', full_name='proto.ListUsersResponse.OrgUser.userName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='proto.ListUsersResponse.OrgUser.userID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAdmin', full_name='proto.ListUsersResponse.OrgUser.isAdmin', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2253,
  serialized_end=2313,
)

_LISTUSERSRESPONSE = _descriptor.Descriptor(
  name='ListUsersResponse',
  full_name='proto.ListUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgUsers', full_name='proto.ListUsersResponse.orgUsers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTUSERSRESPONSE_ORGUSER, ],
  enum_types=[
  ],
  serialized_options=b'\222A~\n\023*\021ListUsersResponse2g\022e{\"orgUsers\":[{\"userName\": \"Donald Trump\", \"userID\": \"donald.trump@whitehouse.gov\", \"isAdmin\": true}]}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2180,
  serialized_end=2445,
)


_REMOVEORGANIZATIONREQUEST = _descriptor.Descriptor(
  name='RemoveOrganizationRequest',
  full_name='proto.RemoveOrganizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='force', full_name='proto.RemoveOrganizationRequest.force', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A0\n\033*\031RemoveOrganizationRequest2\021\022\017{\"force\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2447,
  serialized_end=2542,
)


_REMOVEORGANIZATIONRESPONSE = _descriptor.Descriptor(
  name='RemoveOrganizationResponse',
  full_name='proto.RemoveOrganizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.RemoveOrganizationResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\034*\032RemoveOrganizationResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2544,
  serialized_end=2645,
)


_ADDSHARABLEORGREQUEST = _descriptor.Descriptor(
  name='AddSharableOrgRequest',
  full_name='proto.AddSharableOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='newOrgID', full_name='proto.AddSharableOrgRequest.newOrgID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\027*\025AddSharableOrgRequest2\030\022\026{\"newOrgID\": \"string\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2744,
)


_ADDSHARABLEORGRESPONSE = _descriptor.Descriptor(
  name='AddSharableOrgResponse',
  full_name='proto.AddSharableOrgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.AddSharableOrgResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A/\n\030*\026AddSharableOrgResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2746,
  serialized_end=2839,
)


_REMOVESHARABLEORGREQUEST = _descriptor.Descriptor(
  name='RemoveSharableOrgRequest',
  full_name='proto.RemoveSharableOrgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='removeOrgID', full_name='proto.RemoveSharableOrgRequest.removeOrgID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A9\n\032*\030RemoveSharableOrgRequest2\033\022\031{\"removeOrgID\": \"string\"}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2841,
  serialized_end=2950,
)


_REMOVESHARABLEORGRESPONSE = _descriptor.Descriptor(
  name='RemoveSharableOrgResponse',
  full_name='proto.RemoveSharableOrgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.RemoveSharableOrgResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A2\n\033*\031RemoveSharableOrgResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2952,
  serialized_end=3051,
)


_SETMULTILEVELSHARINGREQUEST = _descriptor.Descriptor(
  name='SetMultiLevelSharingRequest',
  full_name='proto.SetMultiLevelSharingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='proto.SetMultiLevelSharingRequest.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A3\n\035*\033SetMultiLevelSharingRequest2\022\022\020{\"enable\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3053,
  serialized_end=3154,
)


_SETMULTILEVELSHARINGRESPONSE = _descriptor.Descriptor(
  name='SetMultiLevelSharingResponse',
  full_name='proto.SetMultiLevelSharingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='proto.SetMultiLevelSharingResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A5\n\036*\034SetMultiLevelSharingResponse2\023\022\021{\"success\": true}',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3156,
  serialized_end=3261,
)

_LISTUSERSRESPONSE_ORGUSER.containing_type = _LISTUSERSRESPONSE
_LISTUSERSRESPONSE.fields_by_name['orgUsers'].message_type = _LISTUSERSRESPONSE_ORGUSER
DESCRIPTOR.message_types_by_name['RegisterOrganizationRequest'] = _REGISTERORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['RegisterOrganizationResponse'] = _REGISTERORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['RegisterUserRequest'] = _REGISTERUSERREQUEST
DESCRIPTOR.message_types_by_name['RegisterUserResponse'] = _REGISTERUSERRESPONSE
DESCRIPTOR.message_types_by_name['RemoveUserRequest'] = _REMOVEUSERREQUEST
DESCRIPTOR.message_types_by_name['RemoveUserResponse'] = _REMOVEUSERRESPONSE
DESCRIPTOR.message_types_by_name['PromoteUserRequest'] = _PROMOTEUSERREQUEST
DESCRIPTOR.message_types_by_name['PromoteUserResponse'] = _PROMOTEUSERRESPONSE
DESCRIPTOR.message_types_by_name['DemoteUserRequest'] = _DEMOTEUSERREQUEST
DESCRIPTOR.message_types_by_name['DemoteUserResponse'] = _DEMOTEUSERRESPONSE
DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['LogoutRequest'] = _LOGOUTREQUEST
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
DESCRIPTOR.message_types_by_name['ListUsersRequest'] = _LISTUSERSREQUEST
DESCRIPTOR.message_types_by_name['ListUsersResponse'] = _LISTUSERSRESPONSE
DESCRIPTOR.message_types_by_name['RemoveOrganizationRequest'] = _REMOVEORGANIZATIONREQUEST
DESCRIPTOR.message_types_by_name['RemoveOrganizationResponse'] = _REMOVEORGANIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['AddSharableOrgRequest'] = _ADDSHARABLEORGREQUEST
DESCRIPTOR.message_types_by_name['AddSharableOrgResponse'] = _ADDSHARABLEORGRESPONSE
DESCRIPTOR.message_types_by_name['RemoveSharableOrgRequest'] = _REMOVESHARABLEORGREQUEST
DESCRIPTOR.message_types_by_name['RemoveSharableOrgResponse'] = _REMOVESHARABLEORGRESPONSE
DESCRIPTOR.message_types_by_name['SetMultiLevelSharingRequest'] = _SETMULTILEVELSHARINGREQUEST
DESCRIPTOR.message_types_by_name['SetMultiLevelSharingResponse'] = _SETMULTILEVELSHARINGRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RegisterOrganizationRequest = _reflection.GeneratedProtocolMessageType('RegisterOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERORGANIZATIONREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterOrganizationRequest)
  })
_sym_db.RegisterMessage(RegisterOrganizationRequest)

RegisterOrganizationResponse = _reflection.GeneratedProtocolMessageType('RegisterOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERORGANIZATIONRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterOrganizationResponse)
  })
_sym_db.RegisterMessage(RegisterOrganizationResponse)

RegisterUserRequest = _reflection.GeneratedProtocolMessageType('RegisterUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterUserRequest)
  })
_sym_db.RegisterMessage(RegisterUserRequest)

RegisterUserResponse = _reflection.GeneratedProtocolMessageType('RegisterUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RegisterUserResponse)
  })
_sym_db.RegisterMessage(RegisterUserResponse)

RemoveUserRequest = _reflection.GeneratedProtocolMessageType('RemoveUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveUserRequest)
  })
_sym_db.RegisterMessage(RemoveUserRequest)

RemoveUserResponse = _reflection.GeneratedProtocolMessageType('RemoveUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveUserResponse)
  })
_sym_db.RegisterMessage(RemoveUserResponse)

PromoteUserRequest = _reflection.GeneratedProtocolMessageType('PromoteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROMOTEUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.PromoteUserRequest)
  })
_sym_db.RegisterMessage(PromoteUserRequest)

PromoteUserResponse = _reflection.GeneratedProtocolMessageType('PromoteUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROMOTEUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.PromoteUserResponse)
  })
_sym_db.RegisterMessage(PromoteUserResponse)

DemoteUserRequest = _reflection.GeneratedProtocolMessageType('DemoteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEMOTEUSERREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.DemoteUserRequest)
  })
_sym_db.RegisterMessage(DemoteUserRequest)

DemoteUserResponse = _reflection.GeneratedProtocolMessageType('DemoteUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEMOTEUSERRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.DemoteUserResponse)
  })
_sym_db.RegisterMessage(DemoteUserResponse)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LoginRequest)
  })
_sym_db.RegisterMessage(LoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LoginResponse)
  })
_sym_db.RegisterMessage(LoginResponse)

LogoutRequest = _reflection.GeneratedProtocolMessageType('LogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LogoutRequest)
  })
_sym_db.RegisterMessage(LogoutRequest)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ListUsersRequest = _reflection.GeneratedProtocolMessageType('ListUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListUsersRequest)
  })
_sym_db.RegisterMessage(ListUsersRequest)

ListUsersResponse = _reflection.GeneratedProtocolMessageType('ListUsersResponse', (_message.Message,), {

  'OrgUser' : _reflection.GeneratedProtocolMessageType('OrgUser', (_message.Message,), {
    'DESCRIPTOR' : _LISTUSERSRESPONSE_ORGUSER,
    '__module__' : 'accounts_pb2'
    # @@protoc_insertion_point(class_scope:proto.ListUsersResponse.OrgUser)
    })
  ,
  'DESCRIPTOR' : _LISTUSERSRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.ListUsersResponse)
  })
_sym_db.RegisterMessage(ListUsersResponse)
_sym_db.RegisterMessage(ListUsersResponse.OrgUser)

RemoveOrganizationRequest = _reflection.GeneratedProtocolMessageType('RemoveOrganizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveOrganizationRequest)
  })
_sym_db.RegisterMessage(RemoveOrganizationRequest)

RemoveOrganizationResponse = _reflection.GeneratedProtocolMessageType('RemoveOrganizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEORGANIZATIONRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveOrganizationResponse)
  })
_sym_db.RegisterMessage(RemoveOrganizationResponse)

AddSharableOrgRequest = _reflection.GeneratedProtocolMessageType('AddSharableOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSHARABLEORGREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.AddSharableOrgRequest)
  })
_sym_db.RegisterMessage(AddSharableOrgRequest)

AddSharableOrgResponse = _reflection.GeneratedProtocolMessageType('AddSharableOrgResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDSHARABLEORGRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.AddSharableOrgResponse)
  })
_sym_db.RegisterMessage(AddSharableOrgResponse)

RemoveSharableOrgRequest = _reflection.GeneratedProtocolMessageType('RemoveSharableOrgRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESHARABLEORGREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveSharableOrgRequest)
  })
_sym_db.RegisterMessage(RemoveSharableOrgRequest)

RemoveSharableOrgResponse = _reflection.GeneratedProtocolMessageType('RemoveSharableOrgResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESHARABLEORGRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.RemoveSharableOrgResponse)
  })
_sym_db.RegisterMessage(RemoveSharableOrgResponse)

SetMultiLevelSharingRequest = _reflection.GeneratedProtocolMessageType('SetMultiLevelSharingRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMULTILEVELSHARINGREQUEST,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.SetMultiLevelSharingRequest)
  })
_sym_db.RegisterMessage(SetMultiLevelSharingRequest)

SetMultiLevelSharingResponse = _reflection.GeneratedProtocolMessageType('SetMultiLevelSharingResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETMULTILEVELSHARINGRESPONSE,
  '__module__' : 'accounts_pb2'
  # @@protoc_insertion_point(class_scope:proto.SetMultiLevelSharingResponse)
  })
_sym_db.RegisterMessage(SetMultiLevelSharingResponse)


DESCRIPTOR._options = None
_REGISTERORGANIZATIONREQUEST._options = None
_REGISTERORGANIZATIONRESPONSE._options = None
_REGISTERUSERREQUEST._options = None
_REGISTERUSERRESPONSE._options = None
_REMOVEUSERREQUEST._options = None
_REMOVEUSERRESPONSE._options = None
_PROMOTEUSERREQUEST._options = None
_PROMOTEUSERRESPONSE._options = None
_DEMOTEUSERREQUEST._options = None
_DEMOTEUSERRESPONSE._options = None
_LOGINREQUEST._options = None
_LOGINRESPONSE._options = None
_LOGOUTREQUEST._options = None
_LOGOUTRESPONSE._options = None
_LISTUSERSREQUEST._options = None
_LISTUSERSRESPONSE._options = None
_REMOVEORGANIZATIONREQUEST._options = None
_REMOVEORGANIZATIONRESPONSE._options = None
_ADDSHARABLEORGREQUEST._options = None
_ADDSHARABLEORGRESPONSE._options = None
_REMOVESHARABLEORGREQUEST._options = None
_REMOVESHARABLEORGRESPONSE._options = None
_SETMULTILEVELSHARINGREQUEST._options = None
_SETMULTILEVELSHARINGRESPONSE._options = None
# @@protoc_insertion_point(module_scope)



from typing import List

from strongdoc import client
from strongdoc import constants
from strongdoc.proto import search_pb2, strongdoc_pb2_grpc


def search(token, query):
    """
    Search for document that contains a specific word.
    A gRPC connection timeout will be implemented.
    
    :param token:
        The user JWT token.
    :type token:
        `string`
    :param query:
        The query string.
    :type query:
        `string`
    :raises grpc.RpcError:
        Raised by the gRPC library to indicate non-OK-status RPC termination.

    returns:
        The hit list of the search.
    :rtype:
        `Array` of :class:`DocumentResult`
    """
    with client.connect_to_server_with_auth(token) as auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(auth_conn)

        request = search_pb2.SearchRequest(query=query)

        response = client_stub.Search(request, timeout=constants.GRPC_TIMEOUT)

        hits: List[DocumentResult] = []
        for hit_result in response.hits:
            hits.append(DocumentResult(hit_result.docID, hit_result.score))

        return hits


class DocumentResult:
    """
    A class that will hold a single document that matches the search result from the Search query.
    """

    def __init__(self, docid, score):
        """
        Constructs a document that matches the search result

        :param docid:
            The matching document ID
        :type docid:
            `string`
        :param score:
            The score of the matching document
        :type score:
            `float`
        """
        self._docid = docid
        self._score = score

    @property
    def docid(self):
        """
        Get the matching document ID

        returns:
            The matching document ID
        :rtype:
            `string`
        """
        return self._docid

    @docid.setter
    def docid(self, docid):
        """
        Set the matching document ID

        :param docid:
            The matching document ID
        :type docid:
            `string`
        """
        self._docid = docid

    @property
    def score(self):
        """
        Get the score of the matching document

        returns:
            The score of the matching document
        :rtype:
            `float`
        """
        return self._score

    @score.setter
    def score(self, score):
        """
        Set the score of the matching document

        :param score:
            The score of the matching document
        :type score:
            `float`
        """
        self._score = score



from os import path

"""
Location of StrongDoc Service
"""
HOST = 'api.strongsalt.com'
PORT = 9090
CERT = path.join(path.dirname(__file__), "data", "certs", "grpc.root.pem")

"""
Timeout value for the gRPC connection
"""
GRPC_TIMEOUT = 60



from strongdoc import client
from strongdoc.proto import document_pb2, documentNoStore_pb2, strongdoc_pb2_grpc

BLOCK_SIZE = 10000


def _stream_upload_request_generator(doc_name, plaintext, block_size=BLOCK_SIZE):
    request = document_pb2.UploadDocStreamReq(docName=doc_name)

    yield request

    for i in range(0, len(plaintext), block_size):
        block = plaintext[i: i + block_size]
        request = document_pb2.UploadDocStreamReq(plaintext=block)

        yield request


def _stream_encrypt_request_generator(doc_name, plaintext, block_size=BLOCK_SIZE):
    request = documentNoStore_pb2.EncryptDocStreamReq(docName=doc_name)

    yield request

    for i in range(0, len(plaintext), block_size):
        block = plaintext[i: i + block_size]
        request = documentNoStore_pb2.EncryptDocStreamReq(plaintext=block)

        yield request


def _stream_decrypt_request_generator(docid, ciphertext, block_size=BLOCK_SIZE):
    request = documentNoStore_pb2.DecryptDocStreamReq(docID=docid)

    yield request

    for i in range(0, len(ciphertext), block_size):
        block = ciphertext[i: i + block_size]
        request = documentNoStore_pb2.DecryptDocStreamReq(ciphertext=block)

        yield request


# upload_document uploads a document to be stored by strongdoc
def upload_document(token, doc_name, plaintext):
    """
    Uploads a document to the service for storage.

    :param token:
        The user JWT token.
    :type token:
        `string`
    :param doc_name:
        The name of the document.
    :type doc_name:
        `string`
    :param plaintext:
        The text of the document.
    :type plaintext:
        `byte array`
    :returns:
        The uploaded document ID.
    :rtype:
        `string`
    """
    with client.connect_to_server_with_auth(token) as auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(auth_conn)

        request_iterator = _stream_upload_request_generator(doc_name, plaintext)

        response = client_stub.UploadDocumentStream(request_iterator)

        return response.docID


# download_document downloads a document stored in strongdoc
def download_document(token, docid):
    """
    Download a document from the service.

    :param token:
        The user JWT token.
    :type token:
        `string`
    :param docid:
        The ID of the document.
    :type docid:
        `string`
    :returns:
        The downloaded document.
    :rtype:
        `byte array`
    """
    with client.connect_to_server_with_auth(token) as auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(auth_conn)

        request = document_pb2.DownloadDocStreamReq(docID=docid)

        plaintext = b""
        response_iterator = client_stub.DownloadDocumentStream(request)

        for res in response_iterator:
            plaintext += res.plaintext

        return plaintext


# encrypt_document encrypts a document with strongdoc, but does not store the actual document
def encrypt_document(token, doc_name, plaintext):
    """
    Encrypts a document using the service, but do not store it.
    Instead return the encrypted ciphertext.

    :param token:
        The user JWT token.
    :type token:
        `string`
    :param doc_name:
        The name of the document.
    :type doc_name:
        `string`
    :param plaintext:
        The text of the document.
    :type plaintext:
        `byte array`

    Returns
    -------
    docID: string
        The document ID for the uploaded document.
        This ID is needed to decrypt the document.
    ciphertext: byte array
        The encrypted ciphertext of the document.
    """
    with client.connect_to_server_with_auth(token) as auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(auth_conn)

        request_iterator = _stream_encrypt_request_generator(doc_name, plaintext)

        docid = None
        ciphertext = b""
        response_iterator = client_stub.EncryptDocumentStream(request_iterator)

        for res in response_iterator:
            docid = res.docID
            ciphertext += res.ciphertext

        return docid, ciphertext


# decrypt_document encrypts a document with strongdoc. It requires original ciphertext, since the document is not stored
def decrypt_document(token, docid, ciphertext):
    """
    Decrypt a document using the service.
    The user must provide the ciphertext returned during the encryptDocument API call.

    :param token:
        The user JWT token.
    :type token:
        `string`
    :param docid:
        The ID of the document.
    :type docid:
        `string`
    :param ciphertext:
        The document ciphertext to be decrypted.
    :type ciphertext:
        `bye array`
    :returns:
        The decrypted plaintext content of the document.
    :rtype:
        `byte array`
    """
    with client.connect_to_server_with_auth(token) as auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(auth_conn)

        request_iterator = _stream_decrypt_request_generator(docid, ciphertext)

        plaintext = b""
        response_iterator = client_stub.DecryptDocumentStream(request_iterator)

        for res in response_iterator:
            plaintext += res.plaintext

        return plaintext


# remove_document deletes the document from strongdoc storage
def remove_document(token, docid):
    """
    Remove a document from the service.

    :param token:
        The user JWT token.
    :type token:
        `string`
    :param docid:
        The ID of the document.
    :type docid:
        `string`
    :returns:
        Whether the removal was a success.
    :rtype:
        `bool`
    """
    with client.connect_to_server_with_auth(token) as auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(auth_conn)

        request = document_pb2.RemoveDocumentRequest(docID=docid)

        client_stub.RemoveDocument(request)



from strongdoc import client
from strongdoc import constants
from strongdoc.proto import strongdoc_pb2_grpc, accounts_pb2


# register_organization creates an organization
def register_organization(org_name, org_addr, admin_name, admin_password, admin_email):
    """
    Registers a new organization. A new administrator user will also be created.
    New users can be added using this administrator account.
    A gRPC connection timeout will be implemented.

    :param org_name:
        The organization name to create.
    :type org_name:
        `string`
    :param org_addr:
        The organization address.
    :type org_addr:
        `string`
    :param admin_name:
        The organization administrator name.
    :type admin_name:
        `string`
    :param admin_password:
        The organization administrator password.
    :type admin_password:
        `string`
    :param admin_email:
        The organization administrator email.
    :type admin_email:
        `string`
    :raises grpc.RpcError:
        Raised by the gRPC library to indicate non-OK-status RPC termination.

    Returns
    -------
    orgID: string
        The newly created organization ID.
    userID: string
        The newly created user ID.
    """
    with client.connect_to_server_with_no_auth() as no_auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(no_auth_conn)

        request = accounts_pb2.RegisterOrganizationRequest(orgName=org_name,
                                                           orgAddr=org_addr, userName=admin_name,
                                                           password=admin_password, email=admin_email)

        response = client_stub.RegisterOrganization(request, timeout=constants.GRPC_TIMEOUT)

        return response.orgID, response.userID


# remove_organization removes an organization
#    :returns boolean: Whether the removal was a success
def remove_organization(token, force):
    """
    Removes an organization, deleting all data stored with the organization.
    This requires an administrator priviledge.
    A gRPC connection timeout will be implemented.

    :param token: 
        The user JWT token.
    :type token:
        `string`
    :param force: 
        If this is false, removal will fail if there are still data stored with the organization.
        This prevents accidental deletion.
    :type force: 
        `bool`
    :raises grpc.RpcError:
        Raised by the gRPC library to indicate non-OK-status RPC termination.

    :returns:
        Whether the removal was a success.
    :rtype:
        `bool`
    """
    with client.connect_to_server_with_auth(token) as auth_conn:
        client_stub = strongdoc_pb2_grpc.StrongDocServiceStub(auth_conn)

        request = accounts_pb2.RemoveOrganizationRequest(force=force)

        response = client_stub.RemoveOrganization(request, timeout=constants.GRPC_TIMEOUT)

        return response.success
